@@ -35,6 +35,7 @@ import argparse
 import json
 import logging
 import logging.config
+import os
 
 import coloredlogs
 from awsenergylabelerlib import (EnergyLabeler,
@@ -48,9 +49,15 @@ from awsenergylabelerlib import (EnergyLabeler,
                                  LANDING_ZONE_METRIC_EXPORT_TYPES,
                                  ALL_ACCOUNT_EXPORT_TYPES,
                                  ACCOUNT_METRIC_EXPORT_TYPES)
+from awsenergylabelerlib.validations import (validate_allowed_denied_account_ids,
+                                             validate_allowed_denied_regions)
+
 from yaspin import yaspin
 
-from .validators import aws_account_id, ValidatePath, security_hub_region
+from .validators import (ValidatePath,
+                         aws_account_id,
+                         get_mutually_exclusive_args,
+                         security_hub_region)
 
 __author__ = '''Costas Tyfoxylos <ctyfoxylos@schubergphilis.com>'''
 __docformat__ = '''google'''
@@ -82,22 +89,23 @@ def get_arguments():
                         action='store',
                         dest='logger_config',
                         help='The location of the logging config json file',
-                        default='')
+                        default=os.environ.get('AWS_LABELER_LOG_CONFIG', ''))
     parser.add_argument('--log-level',
                         '-L',
                         help='Provide the log level. Defaults to info.',
                         dest='log_level',
                         action='store',
-                        default='info',
+                        default=os.environ.get('AWS_LABELER_LOG_LEVEL', 'info'),
                         choices=['debug',
                                  'info',
                                  'warning',
                                  'error',
                                  'critical'])
-    scope = parser.add_mutually_exclusive_group(required=True)
+    scope = parser.add_mutually_exclusive_group()
     scope.add_argument('--landing-zone-name',
                        '-n',
                        type=str,
+                       default=os.environ.get('AWS_LABELER_LANDING_ZONE_NAME'),
                        help='The name of the Landing Zone to label. '
                             'Mutually exclusive with --single-account-id argument.')
     single_account_action = scope.add_argument('--single-account-id',
@@ -106,17 +114,18 @@ def get_arguments():
                                                dest='single_account_id',
                                                action='store',
                                                type=aws_account_id,
+                                               default=os.environ.get('AWS_LABELER_SINGLE_ACCOUNT_ID'),
                                                help='Run the labeler on a single account. '
                                                     'Mutually exclusive with --landing-zone-name argument.')
     parser.add_argument('--region',
                         '-r',
-                        default=None,
+                        default=os.environ.get('AWS_LABELER_REGION'),
                         type=security_hub_region,
                         required=False,
                         help='The home AWS region, default is None')
     parser.add_argument('--frameworks',
                         '-f',
-                        default=["aws-foundational-security-best-practices"],
+                        default=os.environ.get('AWS_LABELER_FRAMEWORKS', DEFAULT_SECURITY_HUB_FRAMEWORKS),
                         nargs='*',
                         help='The list of applicable frameworks: \
                                 ["aws-foundational-security-best-practices", "cis", "pci-dss"], '
@@ -126,14 +135,14 @@ def get_arguments():
     account_list.add_argument('--allowed-account-ids',
                               '-a',
                               nargs='*',
-                              default=None,
+                              default=os.environ.get('AWS_LABELER_ALLOWED_ACCOUNT_IDS'),
                               required=False,
                               help='A list of AWS Account IDs for which an energy label will be produced. '
                                    'Mutually exclusive with --denied-account-ids and --single-account-id arguments.')
     account_list.add_argument('--denied-account-ids',
                               '-d',
                               nargs='*',
-                              default=None,
+                              default=os.environ.get('AWS_LABELER_DENIED_ACCOUNT_IDS'),
                               required=False,
                               help='A list of AWS Account IDs that will be excluded from producing the energy label. '
                                    'Mutually exclusive with --allowed-account-ids and --single-account-id arguments.')
@@ -141,14 +150,14 @@ def get_arguments():
     region_list.add_argument('--allowed-regions',
                              '-ar',
                              nargs='*',
-                             default=None,
+                             default=os.environ.get('AWS_LABELER_ALLOWED_REGIONS'),
                              required=False,
                              help='A list of AWS regions included in producing the energy label.'
                                   'Mutually exclusive with --denied-regions argument.')
     region_list.add_argument('--denied-regions',
                              '-dr',
                              nargs='*',
-                             default=None,
+                             default=os.environ.get('AWS_LABELER_DENIED_REGIONS'),
                              required=False,
                              help='A list of AWS regions excluded from producing the energy label.'
                                   'Mutually exclusive with --allowed-regions argument.')
@@ -156,6 +165,7 @@ def get_arguments():
                         '-p',
                         action=ValidatePath,
                         required=False,
+                        default=os.environ.get('AWS_LABELER_EXPORT_PATH'),
                         help='Exports a snapshot of chosen data in '
                              'JSON formatted files to the specified directory or S3 location.')
     export_options = parser.add_mutually_exclusive_group()
@@ -164,24 +174,34 @@ def get_arguments():
                                 action='store_const',
                                 dest='export_all',
                                 const=False,
-                                help='Exports metrics/statistics along with findings data in '
+                                default=os.environ.get('AWS_LABELER_EXPORT_METRICS'),
+                                help='Exports metrics/statistics without sensitive findings data in '
                                      'JSON formatted files to the specified directory or S3 location.')
     export_options.add_argument('--export-all',
                                 '-ea',
                                 action='store_const',
                                 dest='export_all',
                                 const=True,
-                                help='Exports metrics/statistics without sensitive findings data in '
+                                default=os.environ.get('AWS_LABELER_EXPORT_ALL', True),
+                                help='Exports metrics/statistics along with sensitive findings data in '
                                      'JSON formatted files to the specified directory or S3 location.')
     parser.add_argument('--to-json',
                         '-j',
                         dest='to_json',
                         action='store_true',
                         required=False,
-                        default=False,
+                        default=os.environ.get('AWS_LABELER_TO_JSON', False),
                         help='Return the report in json format.')
     parser.set_defaults(export_all=True)
     args = parser.parse_args()
+    args.landing_zone_name, args.single_account_id = get_mutually_exclusive_args(args.landing_zone_name,
+                                                                                 args.single_account_id,
+                                                                                 required=True)
+    args.allowed_account_ids, args.denied_account_ids = validate_allowed_denied_account_ids(args.allowed_account_ids,
+                                                                                            args.denied_account_ids)
+    args.allowed_regions, args.denied_regions = validate_allowed_denied_regions(args.allowed_regions,
+                                                                                args.denied_regions)
+    args.frameworks = SecurityHub.validate_frameworks(args.frameworks)
     return args
 
 
@@ -238,6 +258,7 @@ def wait_for_findings(method_name, method_argument, log_level):
 #  pylint: disable=too-many-arguments
 def get_landing_zone_reporting_data(landing_zone_name,
                                     region,
+                                    frameworks,
                                     allowed_account_ids,
                                     denied_account_ids,
                                     allowed_regions,
@@ -249,6 +270,7 @@ def get_landing_zone_reporting_data(landing_zone_name,
     Args:
         landing_zone_name: The name of the landing zone.
         region: The home region of AWS.
+        frameworks: The frameworks to include in scoring.
         allowed_account_ids: The allowed account ids for landing zone inclusion if any.
         denied_account_ids: The allowed account ids for landing zone exclusion if any.
         allowed_regions: The allowed regions for security hub if any.
@@ -265,7 +287,7 @@ def get_landing_zone_reporting_data(landing_zone_name,
                             account_thresholds=ACCOUNT_THRESHOLDS,
                             landing_zone_thresholds=LANDING_ZONE_THRESHOLDS,
                             security_hub_filter=DEFAULT_SECURITY_HUB_FILTER,
-                            frameworks=DEFAULT_SECURITY_HUB_FRAMEWORKS,
+                            frameworks=frameworks,
                             allowed_account_ids=allowed_account_ids,
                             denied_account_ids=denied_account_ids,
                             allowed_regions=allowed_regions,
@@ -290,6 +312,7 @@ def get_landing_zone_reporting_data(landing_zone_name,
 #  pylint: disable=too-many-arguments
 def get_account_reporting_data(account_id,
                                region,
+                               frameworks,
                                allowed_regions,
                                denied_regions,
                                export_all_data_flag,
@@ -299,6 +322,7 @@ def get_account_reporting_data(account_id,
     Args:
         account_id: The ID of the account to get reporting on.
         region: The home region of AWS.
+        frameworks: The frameworks to include in scoring.
         allowed_regions: The allowed regions for security hub if any.
         denied_regions: The denied regions for security hub if any.
         export_all_data_flag: If set all data is going to be exported, else only basic reporting.
@@ -315,7 +339,7 @@ def get_account_reporting_data(account_id,
     query_filter = SecurityHub.calculate_query_filter(DEFAULT_SECURITY_HUB_FILTER,
                                                       allowed_account_ids=[account_id],
                                                       denied_account_ids=None,
-                                                      frameworks=DEFAULT_SECURITY_HUB_FRAMEWORKS)
+                                                      frameworks=frameworks)
     security_hub_findings = wait_for_findings(security_hub.get_findings, query_filter, log_level)
     account.calculate_energy_label(security_hub_findings)
     report_data = [['Account ID:', account.id],
